@@ -13,9 +13,9 @@ use String::ShellQuote;
 use Exporter 'import';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-01'; # DATE
+our $DATE = '2022-07-03'; # DATE
 our $DIST = 'Perinci-CmdLine-POD'; # DIST
-our $VERSION = '0.031'; # VERSION
+our $VERSION = '0.032'; # VERSION
 
 our @EXPORT_OK = qw(gen_pod_for_pericmd_script);
 
@@ -849,7 +849,7 @@ _
                     my $p = "$config_dir/$cfn->{filename}";
                     push @files, $p;
                     push @files_sectpod, $cfn->{section} // '';
-                    push @files_sectpod, "F<$p>\n\n";
+                    push @files_sectpod, "=head2 $p\n\n";
                 }
             }
         }
@@ -1070,7 +1070,7 @@ Perinci::CmdLine::POD - Generate POD for Perinci::CmdLine-based CLI script
 
 =head1 VERSION
 
-This document describes version 0.031 of Perinci::CmdLine::POD (from Perl distribution Perinci-CmdLine-POD), released on 2022-07-01.
+This document describes version 0.032 of Perinci::CmdLine::POD (from Perl distribution Perinci-CmdLine-POD), released on 2022-07-03.
 
 =head1 SYNOPSIS
 
